==> dolfin_0.9.8.orig.tar.gz: dolfin-0.9.8/dolfin/log/Table.h <==
// Copyright (C) 2008-2009 Anders Logg.
// Licensed under the GNU LGPL Version 2.1.
//
// First added:  2008-07-19
// Last changed: 2009-09-15

#ifndef __TABLE_H
#define __TABLE_H

#include <vector>
#include <set>
#include <map>

#include <dolfin/common/Variable.h>
#include <dolfin/common/types.h>

namespace dolfin
{

  class TableEntry;

  /// This class provides storage and pretty-printing for tables.
  /// Example usage:
  ///
  ///   Table table("Timings");
  ///
  ///   table("uBLAS",  "Assemble") = 0.010;
  ///   table("uBLAS",  "Solve")    = 0.020;
  ///   table("PETSc",  "Assemble") = 0.011;
  ///   table("PETSc",  "Solve")    = 0.019;
  ///   table("Epetra", "Assemble") = 0.012;
  ///   table("Epetra", "Solve")    = 0.018;
  ///
  ///   info(table);

  class Table : public Variable
  {
  public:

    /// Create empty table
    Table(std::string title="");

    /// Destructor
    ~Table();

    /// Return table entry
    TableEntry operator() (std::string row, std::string col);

    /// Set value of table entry
    void set(std::string row, std::string col, int value);

    /// Set value of table entry
    void set(std::string row, std::string col, uint value);

    /// Set value of table entry
    void set(std::string row, std::string col, double value);

    /// Set value of table entry
    void set(std::string row, std::string col, std::string value);

    /// Get value of table entry
    std::string get(std::string row, std::string col) const;

    /// Return table title
    std::string title() const;

    /// Assignment operator
    const Table& operator= (const Table& table);

    /// Return informal string representation (pretty-print)
    std::string str(bool verbose) const;

    /// Return informal string representation for LaTeX
    std::string str_latex() const;

  private:

    // Table title
    std::string _title;

    // Rows
    std::vector<std::string> rows;
    std::set<std::string> row_set;

    // Columns
    std::vector<std::string> cols;
    std::set<std::string> col_set;

    // Table values
    std::map<std::pair<std::string, std::string>, std::string> values;

  };

  /// This class represents an entry in a Table

  class TableEntry
  {
  public:

    /// Create table entry
    TableEntry(std::string row, std::string col, Table& table);

    /// Destructor
    ~TableEntry();

    /// Assign value to table entry
    const TableEntry& operator= (uint value);

    /// Assign value to table entry
    const TableEntry& operator= (int value);

    /// Assign value to table entry
    const TableEntry& operator= (double value);

    /// Assign value to table entry
    const TableEntry& operator= (std::string value);

    /// Cast to entry value
    operator std::string() const;

  private:

    // Row
    std::string row;

    // Column
    std::string col;

    // Table
    Table& table;

  };

}

#endif

==> dolfin_0.9.10.orig.tar.gz: dolfin-0.9.10/dolfin/log/Table.h <==
// Copyright (C) 2008-2009 Anders Logg.
// Licensed under the GNU LGPL Version 2.1.
//
// First added:  2008-07-19
// Last changed: 2010-11-11

#ifndef __TABLE_H
#define __TABLE_H

#include <map>
#include <set>
#include <vector>
#include <dolfin/common/types.h>
#include <dolfin/common/Variable.h>

namespace dolfin
{

  class TableEntry;

  /// This class provides storage and pretty-printing for tables.
  /// Example usage:
  ///
  ///   Table table("Timings");
  ///
  ///   table("uBLAS",  "Assemble") = 0.010;
  ///   table("uBLAS",  "Solve")    = 0.020;
  ///   table("PETSc",  "Assemble") = 0.011;
  ///   table("PETSc",  "Solve")    = 0.019;
  ///   table("Epetra", "Assemble") = 0.012;
  ///   table("Epetra", "Solve")    = 0.018;
  ///
  ///   info(table);

  class Table : public Variable
  {
  public:

    /// Create empty table
    Table(std::string title="");

    /// Destructor
    ~Table();

    /// Return table entry
    TableEntry operator() (std::string row, std::string col);

    /// Set value of table entry
    void set(std::string row, std::string col, int value);

    /// Set value of table entry
    void set(std::string row, std::string col, uint value);

    /// Set value of table entry
    void set(std::string row, std::string col, double value);

    /// Set value of table entry
    void set(std::string row, std::string col, std::string value);

    /// Get value of table entry
    std::string get(std::string row, std::string col) const;

    /// Get value of table entry
    double get_value(std::string row, std::string col) const;

    /// Return table title
    std::string title() const;

    /// Assignment operator
    const Table& operator= (const Table& table);

    /// Return informal string representation (pretty-print)
    std::string str(bool verbose) const;

    /// Return informal string representation for LaTeX
    std::string str_latex() const;

  private:

    // Table title
    std::string _title;

    // Rows
    std::vector<std::string> rows;
    std::set<std::string> row_set;

    // Columns
    std::vector<std::string> cols;
    std::set<std::string> col_set;

    // Table values as strings
    std::map<std::pair<std::string, std::string>, std::string> values;

    // Table values as doubles
    std::map<std::pair<std::string, std::string>, double> dvalues;

  };

  /// This class represents an entry in a Table

  class TableEntry
  {
  public:

    /// Create table entry
    TableEntry(std::string row, std::string col, Table& table);

    /// Destructor
    ~TableEntry();

    /// Assign value to table entry
    const TableEntry& operator= (uint value);

    /// Assign value to table entry
    const TableEntry& operator= (int value);

    /// Assign value to table entry
    const TableEntry& operator= (double value);

    /// Assign value to table entry
    const TableEntry& operator= (std::string value);

    /// Cast to entry value
    operator std::string() const;

  private:

    // Row
    std::string row;

    // Column
    std::string col;

    // Table
    Table& table;

  };

}

#endif
